@@ -13,19 +13,19 @@ int main(int argc, char *argv[])
 
     libdatadir = getenv("LIBDATADIR");
     if (libdatadir == NULL)
-	libdatadir = LIBDATADIR;
+        libdatadir = LIBDATADIR;
 
     snprintf(conjFN, sizeof(conjFN), "%s/conjugation-fr.xml", libdatadir);
     snprintf(verbsFN, sizeof(verbsFN), "%s/verbs-fr.xml", libdatadir);
 
-    verbiste_init(conjFN, verbsFN);
+    verbiste_init(conjFN, verbsFN, "fr");
 
     if (argc < 2)
     {
-	printf("deconjugator.c: demo of the C API of Verbiste\n");
-	printf("Usage: deconjugator VERB\n");
-	printf("Note: this program expects Latin-1 and writes Latin-1.\n");
-	return EXIT_FAILURE;
+        printf("deconjugator.c: demo of the C API of Verbiste\n");
+        printf("Usage: deconjugator VERB\n");
+        printf("Note: this program expects Latin-1 and writes Latin-1.\n");
+        return EXIT_FAILURE;
     }
 
 
@@ -33,21 +33,21 @@ int main(int argc, char *argv[])
     vec = verbiste_deconjugate(lower_latin1);
     verbiste_free_string(lower_latin1);
 
-    if (vec == NULL) 
-    {        
-	fprintf(stderr, "Internal error in libverbiste.\n");
-	return EXIT_FAILURE;
+    if (vec == NULL)
+    {
+        fprintf(stderr, "Internal error in libverbiste.\n");
+        return EXIT_FAILURE;
     }
 
 
     for (i = 0; vec[i].infinitive_verb != NULL; i++)
     {
-	printf("%s, %s, %s, %d, %s\n", 
-		    vec[i].infinitive_verb,
-		    (const char*) verbiste_get_mode_name(vec[i].mode),
-		    (const char*) verbiste_get_tense_name(vec[i].tense),
-		    vec[i].person,
-		    vec[i].plural ? "plural" : "singular");
+        printf("%s, %s, %s, %d, %s\n",
+                    vec[i].infinitive_verb,
+                    (const char*) verbiste_get_mode_name(vec[i].mode),
+                    (const char*) verbiste_get_tense_name(vec[i].tense),
+                    vec[i].person,
+                    vec[i].plural ? "plural" : "singular");
     }
     printf("\n");
 
