@@ -1,8 +1,8 @@
-/*  $Id: french-deconjugator.cpp,v 1.16 2010/04/18 20:10:35 sarrazip Exp $
+/*  $Id: french-deconjugator.cpp,v 1.21 2010/07/04 17:06:35 sarrazip Exp $
     french-deconjugator.cpp - Analyzer of conjugated French verbs
 
     verbiste - French conjugation system
-    Copyright (C) 2003-2009 Pierre Sarrazin <http://sarrazip.com/>
+    Copyright (C) 2003-2010 Pierre Sarrazin <http://sarrazip.com/>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -49,10 +49,11 @@ static const char *commandName = "french-deconjugator";
 #if defined(ENABLE_NLS) && defined(HAVE_GETOPT_LONG)
 static struct option knownOptions[] =
 {
-    { "help",          no_argument,       NULL, 'h' },
-    { "version",       no_argument,       NULL, 'v' },
-    { "utf8",          no_argument,       NULL, 'u' },
-    { "all-infinitives",no_argument,      NULL, 'i' },
+    { "help",            no_argument,       NULL, 'h' },
+    { "version",         no_argument,       NULL, 'v' },
+    { "lang",            required_argument, NULL, 'l' },
+    { "utf8",            no_argument,       NULL, 'u' },
+    { "all-infinitives", no_argument,       NULL, 'i' },
 
     { NULL, 0, NULL, 0 }  // marks the end
 };
@@ -63,8 +64,11 @@ class DeconjugatorCommand : public Command
 {
 public:
 
-    DeconjugatorCommand(bool utf8Mode) throw(logic_error)
-      : Command(utf8Mode)
+    DeconjugatorCommand(const string &conjugationFilename,
+                        const string &verbsFilename,
+                        const string &langCode,
+                        bool utf8Mode) throw(logic_error)
+      : Command(conjugationFilename, verbsFilename, langCode, utf8Mode)
     {
     }
 
@@ -90,30 +94,30 @@ DeconjugatorCommand::processInputWord(const string &inputWord)
 
     // Display the results in Latin-1, with a terminating empty line:
     for (vector<InflectionDesc>::const_iterator it = v.begin();
-					    it != v.end(); it++)
+                                            it != v.end(); it++)
     {
-	const InflectionDesc &d = *it;
-	string inf = d.infinitive;
+        const InflectionDesc &d = *it;
+        string inf = d.infinitive;
 
-	if (utf8Mode)
-	{
-	    try
-	    {
-		inf = fvd->latin1ToUTF8(inf);
-	    }
-	    catch (int)
-	    {
-		// Conversion failed. Leave 'inf' as is.
-	    }
-	}
+        if (utf8Mode)
+        {
+            try
+            {
+                inf = fvd->latin1ToUTF8(inf);
+            }
+            catch (int)
+            {
+                // Conversion failed. Leave 'inf' as is.
+            }
+        }
 
-	cout 
-	    << inf
-	    << ", " << FrenchVerbDictionary::getModeName(d.mtpn.mode)
-	    << ", " << FrenchVerbDictionary::getTenseName(d.mtpn.tense)
-	    << ", " << int(d.mtpn.person)
-	    << ", " << (d.mtpn.plural ? "plural" : "singular")
-	    << "\n";
+        cout
+            << inf
+            << ", " << FrenchVerbDictionary::getModeName(d.mtpn.mode)
+            << ", " << FrenchVerbDictionary::getTenseName(d.mtpn.tense)
+            << ", " << int(d.mtpn.person)
+            << ", " << (d.mtpn.plural ? "plural" : "singular")
+            << "\n";
     }
     cout << endl;
 }
@@ -139,16 +143,18 @@ displayHelp()
 
     cout <<
 "\n"
-"Copyright (C) 2003-2009 Pierre Sarrazin <http://sarrazip.com/>\n"
+"Copyright (C) " COPYRIGHT_YEARS " Pierre Sarrazin <http://sarrazip.com/>\n"
 "This program is free software; you may redistribute it under the terms of\n"
 "the GNU General Public License.  This program has absolutely no warranty.\n"
     ;
 
     cout <<
 "\n"
-"Known options:\n"
+"Options:\n"
 "--help             Display this help page and exit\n"
 "--version          Display this program's version number and exit\n"
+"--lang=L           Select language L (fr for French, it for Italian)\n"
+"                   Default is French.\n"
 "--utf8             Assume that the terminal uses UTF-8 instead of Latin-1\n"
 "--all-infinitives  Print the names of all known verbs, one per line (unsorted)\n"
 "\n"
@@ -164,6 +170,7 @@ main(int argc, char *argv[])
     setlocale(LC_CTYPE, "");
     bool utf8Mode = (strcmp(nl_langinfo(CODESET), "UTF-8") == 0);
     bool listAllInfinitives = false;
+    string langCode = "fr";
 
     #if defined(ENABLE_NLS) && defined(HAVE_GETOPT_LONG)
 
@@ -172,33 +179,42 @@ main(int argc, char *argv[])
     int c;
     do
     {
-	c = getopt_long(argc, argv, "hv", knownOptions, NULL);
+        c = getopt_long(argc, argv, "hv", knownOptions, NULL);
 
-	switch (c)
-	{
-	    case EOF:
-		break;  // nothing to do
+        switch (c)
+        {
+            case EOF:
+                break;  // nothing to do
 
-	    case 'v':
-		displayVersionNo();
-		return EXIT_SUCCESS;
+            case 'l':
+                langCode = optarg;
+                if (langCode != "fr" && langCode != "it")
+                {
+                    cerr << commandName << ": invalid language code " << optarg << "\n";
+                    return EXIT_FAILURE;
+                }
+                break;
 
-	    case 'h':
-		displayHelp();
-		return EXIT_SUCCESS;
+            case 'v':
+                displayVersionNo();
+                return EXIT_SUCCESS;
 
-	    case 'u':
-	    	utf8Mode = true;
-		break;
+            case 'h':
+                displayHelp();
+                return EXIT_SUCCESS;
 
-	    case 'i':
-		listAllInfinitives = true;
-		break;
+            case 'u':
+                    utf8Mode = true;
+                break;
 
-	    default:
-		displayHelp();
-		return EXIT_FAILURE;
-	}
+            case 'i':
+                listAllInfinitives = true;
+                break;
+
+            default:
+                displayHelp();
+                return EXIT_FAILURE;
+        }
     } while (c != EOF && c != '?');
 
     #else
@@ -207,10 +223,24 @@ main(int argc, char *argv[])
 
     #endif
 
-    DeconjugatorCommand cmd(utf8Mode);
+    try
+    {
+        if (langCode != "fr" && langCode != "it")
+            langCode = "fr";
 
-    if (listAllInfinitives)
-	return cmd.listAllInfinitives(cout);
+        string conjFN, verbsFN;
+        FrenchVerbDictionary::getXMLFilenames(conjFN, verbsFN, langCode);
 
-    return cmd.run(argc - optind, argv + optind);
+        DeconjugatorCommand cmd(conjFN, verbsFN, langCode, utf8Mode);
+
+        if (listAllInfinitives)
+            return cmd.listAllInfinitives(cout);
+
+        return cmd.run(argc - optind, argv + optind);
+    }
+    catch (const exception &e)
+    {
+        cerr << commandName << ": exception: " << e.what() << endl;
+        return EXIT_FAILURE;
+    }
 }
